import React, { useState, useEffect } from 'react';
import ReactDOM from 'react-dom';
import {
  csv,
  scaleLinear,
  max,
  select,
  axisBottom,
  axisLeft,
} from 'd3';

const csvUrl =
  'https://raw.githubusercontent.com/kusuma63663/ICE-6/main/Iris.csv';
const height = 500;
const width = 600;
const margin = { top: 20, right: 20, bottom: 70, left: 70 };

const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    const row = (d) => {
      d.SepalLengthCm = +d.SepalLengthCm;
      d.SepalWidthCm = +d.SepalWidthCm;
      return d;
    };

    csv(csvUrl, row).then((data) => {
      setData(data);
    });
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;

  const xScale = scaleLinear()
    .domain([0, max(data, (d) => d.SepalWidthCm)])
    .range([0, innerWidth]);

  const yScale = scaleLinear()
    .domain([0, max(data, (d) => d.SepalLengthCm)])
    .range([innerHeight, 0]);

  return (
    <svg width={width} height={height}>
      <g
        transform={`translate(${margin.left},${margin.top})`}
      >
        {data.map((d, i) => (
          <circle
            key={i}
            cx={xScale(d.SepalWidthCm)}
            cy={yScale(d.SepalLengthCm)}
            r={3}
            fill="#2ca02c"
          />
        ))}
        <g
          transform={`translate(0,${innerHeight})`}
          ref={(node) =>
            select(node).call(axisBottom(xScale))
          }
        />
        <g
          ref={(node) =>
            select(node).call(axisLeft(yScale))
          }
        />
        <text
          x={innerWidth / 2}
          y={innerHeight + margin.bottom - 10}
          textAnchor="middle"
          fontSize="16"
        >
          Sepal Width (cm)
        </text>
        <text
          transform={`rotate(-90) translate(${-innerHeight / 2},${-margin.left + 20})`}
          textAnchor="middle"
          fontSize="16"
        >
          Sepal Length (cm)
        </text>
      </g>
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
